==> fightorflight-fabric-0.9.0-sources.jar: me/rufia/fightorflight/mixin/EmptyPokeBallEntityMixin.java <==
package me.rufia.fightorflight.mixin;

import com.cobblemon.mod.common.entity.pokeball.EmptyPokeBallEntity;
import com.cobblemon.mod.common.entity.pokemon.PokemonEntity;
import me.rufia.fightorflight.CobblemonFightOrFlight;
import me.rufia.fightorflight.PokemonInterface;
import me.rufia.fightorflight.utils.PokemonUtils;
import net.minecraft.class_1299;
import net.minecraft.class_1682;
import net.minecraft.class_1937;
import net.minecraft.class_3966;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

@Mixin(EmptyPokeBallEntity.class)
public abstract class EmptyPokeBallEntityMixin extends class_1682 {
    @Shadow(remap = false)
    private PokemonEntity capturingPokemon;

    @Shadow(remap = false)
    public abstract EmptyPokeBallEntity.CaptureState getCaptureState();

    @Shadow
    protected abstract void drop();

    protected EmptyPokeBallEntityMixin(class_1299<? extends class_1682> entityType, class_1937 level) {
        super(entityType, level);
    }

    @Inject(method = "breakFree", at = @At("HEAD"), remap = false)
    private void breakFreeInject(CallbackInfo ci) {
        if (capturingPokemon != null && this.method_24921() != null) {
            ((PokemonInterface) capturingPokemon).setCapturedBy(this.method_24921().method_5628());
        }
    }

    @Inject(method = "onHitEntity", at = @At("HEAD"), cancellable = true)
    private void onHitEntityMixin(class_3966 hitResult, CallbackInfo ci) {
        if (getCaptureState() == EmptyPokeBallEntity.CaptureState.NOT) {
            if (!method_37908().field_9236 && hitResult.method_17782() instanceof PokemonEntity pokemonEntity) {
                if (!CobblemonFightOrFlight.commonConfig().aggressive_pokemon_catchable && PokemonUtils.shouldFightTarget(pokemonEntity) && pokemonEntity.method_5968() != null) {
                    drop();
                    ci.cancel();
                }
            }
        }
    }
}

==> fightorflight-fabric-0.10.0-sources.jar: me/rufia/fightorflight/mixin/EmptyPokeBallEntityMixin.java <==
package me.rufia.fightorflight.mixin;

import com.cobblemon.mod.common.entity.pokeball.EmptyPokeBallEntity;
import com.cobblemon.mod.common.entity.pokemon.PokemonEntity;
import me.rufia.fightorflight.CobblemonFightOrFlight;
import me.rufia.fightorflight.PokemonInterface;
import me.rufia.fightorflight.utils.PokemonUtils;
import net.minecraft.class_1299;
import net.minecraft.class_1682;
import net.minecraft.class_1937;
import net.minecraft.class_3966;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

@Mixin(EmptyPokeBallEntity.class)
public abstract class EmptyPokeBallEntityMixin extends class_1682 {
    @Shadow(remap = false)
    private PokemonEntity capturingPokemon;

    @Shadow(remap = false)
    public abstract EmptyPokeBallEntity.CaptureState getCaptureState();

    @Shadow(remap = false)
    protected abstract void drop();

    protected EmptyPokeBallEntityMixin(class_1299<? extends class_1682> entityType, class_1937 level) {
        super(entityType, level);
    }

    @Inject(method = "breakFree", at = @At("HEAD"), remap = false)
    private void breakFreeInject(CallbackInfo ci) {
        if (capturingPokemon != null && this.method_24921() != null) {
            ((PokemonInterface) capturingPokemon).setCapturedBy(this.method_24921().method_5628());
        }
    }

    @Inject(method = "onHitEntity", at = @At("HEAD"), cancellable = true)
    private void onHitEntityMixin(class_3966 hitResult, CallbackInfo ci) {
        if (getCaptureState() == EmptyPokeBallEntity.CaptureState.NOT) {
            if (!method_37908().field_9236 && hitResult.method_17782() instanceof PokemonEntity pokemonEntity) {
                if (!CobblemonFightOrFlight.commonConfig().aggressive_pokemon_catchable && PokemonUtils.shouldFightTarget(pokemonEntity) && PokemonUtils.getTarget(pokemonEntity) != null) {
                    drop();
                    ci.cancel();
                }
            }
        }
    }
}
